# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Testing that <pre> elements properly handle indents.

    foo
    bar
      tab-indented
        four-space indented
    baz

    Indented element,
    content at same level.
      This line is further indented.
    Back to the initial indentation.

    Another indented element,
    but now the content is indented a level past the element.
      This line is further indented,
    and now we’re back.

      This line is indented further than the content is in general.
    Here’s the normal indentation:
    these lines should be against the edge.
      This line is indented again.
    And back to normal.

        This is twice-indented.
      This is once-indented.
    And this line is not indented - it’s even indented less than the element.
      Once again.
        Twice again.